@@ -613,6 +613,7 @@ types: list[str] = [
     "AWS::IVS::EncoderConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
+    "AWS::IVS::PublicKey",
     "AWS::IVS::RecordingConfiguration",
     "AWS::IVS::Stage",
     "AWS::IVS::StorageConfiguration",
@@ -1435,7 +1436,6 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
-    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1914,6 +1914,15 @@ cached: list[str] = [
     "aws-iotwireless-taskdefinition.json",
     "aws-iotwireless-wirelessdevice.json",
     "aws-iotwireless-wirelessgateway.json",
+    "aws-ivs-channel.json",
+    "aws-ivs-encoderconfiguration.json",
+    "aws-ivs-playbackkeypair.json",
+    "aws-ivs-playbackrestrictionpolicy.json",
+    "aws-ivs-publickey.json",
+    "aws-ivs-recordingconfiguration.json",
+    "aws-ivs-stage.json",
+    "aws-ivs-storageconfiguration.json",
+    "aws-ivs-streamkey.json",
     "aws-ivschat-loggingconfiguration.json",
     "aws-ivschat-room.json",
     "aws-kafkaconnect-connector.json",
@@ -1973,7 +1982,6 @@ cached: list[str] = [
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
     "aws-location-apikey.json",
-    "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
     "aws-location-routecalculator.json",
@@ -2044,7 +2052,6 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
-    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
