@@ -1404,7 +1404,6 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
-    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1513,11 +1512,14 @@ cached: list[str] = [
     "aws-dax-parametergroup.json",
     "aws-dax-subnetgroup.json",
     "aws-deadline-farm.json",
+    "aws-deadline-fleet.json",
     "aws-deadline-licenseendpoint.json",
     "aws-deadline-meteredproduct.json",
     "aws-deadline-monitor.json",
+    "aws-deadline-queue.json",
     "aws-deadline-queueenvironment.json",
     "aws-deadline-queuefleetassociation.json",
+    "aws-deadline-storageprofile.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
     "aws-detective-organizationadmin.json",
@@ -1895,6 +1897,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
