@@ -618,6 +618,7 @@ types: list[str] = [
     "AWS::IVS::EncoderConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
+    "AWS::IVS::PublicKey",
     "AWS::IVS::RecordingConfiguration",
     "AWS::IVS::Stage",
     "AWS::IVS::StorageConfiguration",
@@ -1447,7 +1448,6 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
-    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1612,6 +1612,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1671,6 +1672,7 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1831,6 +1833,7 @@ cached: list[str] = [
     "aws-iam-accesskey.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -1929,6 +1932,7 @@ cached: list[str] = [
     "aws-ivs-encoderconfiguration.json",
     "aws-ivs-playbackkeypair.json",
     "aws-ivs-playbackrestrictionpolicy.json",
+    "aws-ivs-publickey.json",
     "aws-ivs-recordingconfiguration.json",
     "aws-ivs-stage.json",
     "aws-ivs-storageconfiguration.json",
@@ -1960,6 +1964,7 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -1982,7 +1987,6 @@ cached: list[str] = [
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
-    "aws-location-apikey.json",
     "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
@@ -2052,7 +2056,6 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
-    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -2153,8 +2156,6 @@ cached: list[str] = [
     "aws-qldb-stream.json",
     "aws-quicksight-analysis.json",
     "aws-quicksight-dashboard.json",
-    "aws-quicksight-dataset.json",
-    "aws-quicksight-datasource.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
@@ -2236,6 +2237,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
