@@ -595,6 +595,7 @@ types: list[str] = [
     "AWS::IVS::EncoderConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
+    "AWS::IVS::PublicKey",
     "AWS::IVS::RecordingConfiguration",
     "AWS::IVS::Stage",
     "AWS::IVS::StorageConfiguration",
@@ -1422,7 +1423,6 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
-    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1560,7 +1560,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1621,7 +1620,6 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
-    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1744,7 +1742,6 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
-    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1794,6 +1791,7 @@ cached: list[str] = [
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -1888,6 +1886,7 @@ cached: list[str] = [
     "aws-ivs-encoderconfiguration.json",
     "aws-ivs-playbackkeypair.json",
     "aws-ivs-playbackrestrictionpolicy.json",
+    "aws-ivs-publickey.json",
     "aws-ivs-recordingconfiguration.json",
     "aws-ivs-stage.json",
     "aws-ivs-storageconfiguration.json",
@@ -1926,6 +1925,7 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -2022,7 +2022,6 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
-    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -2209,6 +2208,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
