@@ -675,6 +675,7 @@ cached: list[str] = [
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-domainname.json",
+    "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
@@ -832,7 +833,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -881,7 +881,6 @@ cached: list[str] = [
     "aws-ec2-verifiedaccesstrustprovider.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
-    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
@@ -953,7 +952,6 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
-    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -962,6 +960,7 @@ cached: list[str] = [
     "aws-glue-partition.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
+    "aws-glue-trigger.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -1004,7 +1003,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
@@ -1077,7 +1075,6 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
-    "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
