@@ -707,7 +707,6 @@ cached: list[str] = [
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
-    "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-stage.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
@@ -780,6 +779,7 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-codestarconnections-connection.json",
     "aws-config-configurationaggregator.json",
@@ -836,7 +836,6 @@ cached: list[str] = [
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -857,11 +856,13 @@ cached: list[str] = [
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
+    "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
+    "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
@@ -886,7 +887,6 @@ cached: list[str] = [
     "aws-ec2-verifiedaccessinstance.json",
     "aws-ec2-verifiedaccesstrustprovider.json",
     "aws-ec2-vpc.json",
-    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
@@ -945,7 +945,6 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
-    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1033,7 +1032,6 @@ cached: list[str] = [
     "aws-lakeformation-permissions.json",
     "aws-lakeformation-resource.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-function.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
