@@ -638,6 +638,7 @@ types: list[str] = [
     "AWS::IVS::EncoderConfiguration",
     "AWS::IVS::PlaybackKeyPair",
     "AWS::IVS::PlaybackRestrictionPolicy",
+    "AWS::IVS::PublicKey",
     "AWS::IVS::RecordingConfiguration",
     "AWS::IVS::Stage",
     "AWS::IVS::StorageConfiguration",
@@ -1493,7 +1494,6 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
-    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1660,6 +1660,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1720,6 +1721,7 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1890,6 +1892,7 @@ cached: list[str] = [
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -1982,6 +1985,7 @@ cached: list[str] = [
     "aws-ivs-encoderconfiguration.json",
     "aws-ivs-playbackkeypair.json",
     "aws-ivs-playbackrestrictionpolicy.json",
+    "aws-ivs-publickey.json",
     "aws-ivs-recordingconfiguration.json",
     "aws-ivs-stage.json",
     "aws-ivs-storageconfiguration.json",
@@ -2045,7 +2049,6 @@ cached: list[str] = [
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
     "aws-location-apikey.json",
-    "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
     "aws-location-routecalculator.json",
@@ -2113,7 +2116,6 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
-    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -2317,6 +2319,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
