@@ -5,7 +5,9 @@ SPDX-License-Identifier: MIT-0
 
 import regex as re
 
+from cfnlint._typing import Path, RuleMatches
 from cfnlint.rules import CloudFormationLintRule, RuleMatch
+from cfnlint.template import Template
 
 
 class CodepipelineStageActions(CloudFormationLintRule):
@@ -158,8 +160,9 @@ class CodepipelineStageActions(CloudFormationLintRule):
             min_, max_ = constraints[constraint_key]
             if not min_ <= artifact_count <= max_:
                 message = (
-                    f'Action "{action["Name"]}" declares {artifact_count} {artifact_type} which is not in '
-                    f"expected range [{min_}, {max_}]."
+                    f'Action "{action["Name"]}" declares'
+                    f" {artifact_count} {artifact_type} which is not in expected range"
+                    f" [{min_}, {max_}]."
                 )
                 if scenario:
                     scenario_text = " and ".join(
@@ -170,8 +173,9 @@ class CodepipelineStageActions(CloudFormationLintRule):
         else:
             if artifact_count != constraints[constraint_key]:
                 message = (
-                    f'Action "{action["Name"]}" declares {artifact_count} {artifact_type} which is not the '
-                    f"expected number [{constraints[constraint_key]}]."
+                    f'Action "{action["Name"]}" declares'
+                    f" {artifact_count} {artifact_type} which is not the expected"
+                    f" number [{constraints[constraint_key]}]."
                 )
                 if scenario:
                     scenario_text = " and ".join(
@@ -197,7 +201,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
             )
         elif isinstance(version, (str)):
             if not LENGTH_MIN <= len(version) <= LENGTH_MAX:
-                message = "Version string ({0}) must be between {1} and {2} characters in length."
+                message = (
+                    "Version string ({0}) must be between {1} and {2} characters in"
+                    " length."
+                )
                 if scenario:
                     scenario_text = " and ".join(
                         [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
@@ -226,7 +233,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
         action_name = action.get("Name")
         if isinstance(action_name, str):
             if action.get("Name") in action_names:
-                message = f'All action names within a stage must be unique ({action.get("Name")}).'
+                message = (
+                    "All action names within a stage must be unique"
+                    f" ({action.get('Name')})."
+                )
                 if scenario:
                     scenario_text = " and ".join(
                         [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
@@ -238,7 +248,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
         return matches
 
     def check_artifact_names(self, action, path, artifact_names, scenario):
-        """Check that output artifact names are unique and inputs are from previous stage outputs."""
+        """
+        Check that output artifact names are unique and
+        inputs are from previous stage outputs.
+        """
         matches = []
 
         input_artifacts = action.get("InputArtifacts")
@@ -246,8 +259,12 @@ class CodepipelineStageActions(CloudFormationLintRule):
             for input_artifact in input_artifacts:
                 artifact_name = input_artifact.get("Name")
                 if isinstance(artifact_name, str):
-                    if not artifact_name in artifact_names:
-                        message = f"Every input artifact for an action must match the output artifact of an action earlier in the pipeline ({artifact_name})."
+                    if artifact_name not in artifact_names:
+                        message = (
+                            "Every input artifact for an action must match the output"
+                            " artifact of an action earlier in the pipeline"
+                            f" ({artifact_name})."
+                        )
                         if scenario:
                             scenario_text = " and ".join(
                                 [
@@ -266,7 +283,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 artifact_name = output_artifact.get("Name")
                 if isinstance(artifact_name, str):
                     if artifact_name in artifact_names:
-                        message = f"Every output artifact in the pipeline must have a unique name. ({artifact_name})"
+                        message = (
+                            "Every output artifact in the pipeline must have a unique"
+                            f" name. ({artifact_name})"
+                        )
                         matches.append(
                             RuleMatch(path + ["OutputArtifacts", "Name"], message)
                         )
@@ -274,21 +294,21 @@ class CodepipelineStageActions(CloudFormationLintRule):
 
         return matches
 
-    def match(self, cfn):
+    def match(self, cfn: Template) -> RuleMatches:
         """Check that stage actions are set up properly."""
-        matches = []
+        matches: RuleMatches = []
 
-        resources = cfn.get_resource_properties(["AWS::CodePipeline::Pipeline"])
-
-        for resource in resources:
-            scenarios = cfn.get_object_without_nested_conditions(
-                resource["Value"], resource["Path"]
-            )
+        for resource_name, resource_value in cfn.get_resources(
+            "AWS::CodePipeline::Pipeline"
+        ).items():
+            path: Path = ["Resources", resource_name, "Properties"]
+            properties = resource_value.get("Properties", {})
+            scenarios = cfn.get_object_without_nested_conditions(properties, path)
             for scenario in scenarios:
                 conditions = scenario.get("Scenario")
-                path = resource["Path"] + ["Stages"]
+                path = path + ["Stages"]
                 properties = scenario.get("Object")
-                artifact_names = set()
+                artifact_names: set[str] = set()
 
                 s_stages = properties.get("Stages")
                 if not isinstance(s_stages, list):
@@ -297,11 +317,12 @@ class CodepipelineStageActions(CloudFormationLintRule):
                     )
                     return matches
                 for s_stage_i, s_stage_v in enumerate(s_stages):
-                    action_names = set()
+                    action_names: set[str] = set()
                     s_actions = s_stage_v.get("Actions")
                     if not isinstance(s_actions, list):
                         self.logger.debug(
-                            "Actions not list. Should have been caught by generic linting."
+                            "Actions not list. Should have been caught by generic"
+                            " linting."
                         )
                         return matches
 
@@ -333,8 +354,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
                             )
                         except AttributeError as err:
                             self.logger.debug(
-                                "Got AttributeError. Should have been caught by generic linting. "
-                                "Ignoring the error here: %s",
+                                (
+                                    "Got AttributeError. Should have been caught by"
+                                    " generic linting. Ignoring the error here: %s"
+                                ),
                                 str(err),
                             )
 
