@@ -10,8 +10,9 @@ import json
 import logging
 import random
 import string
+import sys
 from copy import deepcopy
-from typing import Any, Iterable, List, Mapping, MutableMapping, Optional, Tuple
+from typing import Any, Iterator, Mapping, MutableMapping, Tuple
 
 import regex as re
 
@@ -29,19 +30,19 @@ _SCALAR_TYPES = (str, int, float, bool)
 
 
 class _ResolveError(Exception):
-    def __init__(self, message: str, key: str) -> None:
+    def __init__(self, message: str, key: Any) -> None:
         super().__init__(message)
         self.key = key
 
 
 class _ValueError(Exception):
-    def __init__(self, message: str, key: str) -> None:
+    def __init__(self, message: str, key: Any) -> None:
         super().__init__(message)
         self.key = key
 
 
 class _TypeError(Exception):
-    def __init__(self, message: str, key: str) -> None:
+    def __init__(self, message: str, key: Any) -> None:
         super().__init__(message)
         self.key = key
 
@@ -54,7 +55,7 @@ def language_extension(cfn: Any) -> TransformResult:
         LOGGER.debug(e, exc_info=True)
         # pylint: disable=import-outside-toplevel
         from cfnlint.match import Match  # pylint: disable=cyclic-import
-        from cfnlint.rules import TransformError  # pylint: disable=cyclic-import
+        from cfnlint.rules.errors import TransformError  # pylint: disable=cyclic-import
 
         message = "Error transforming template: {0}"
         if hasattr(e.key, "start_mark"):
@@ -71,32 +72,28 @@ def language_extension(cfn: Any) -> TransformResult:
             em_column = 1
 
         return [
-            Match(
-                sm_line,
-                sm_column,
-                em_line,
-                em_column,
-                cfn.filename,
-                TransformError(),
-                message.format(str(e)),
+            Match.create(
+                linenumber=sm_line,
+                columnnumber=sm_column,
+                linenumberend=em_line,
+                columnnumberend=em_column,
+                filename=cfn.filename,
+                rule=TransformError(),
+                message=message.format(str(e)),
             )
         ], None
     except Exception as e:  # pylint: disable=broad-exception-caught
         LOGGER.debug(e, exc_info=True)
         # pylint: disable=import-outside-toplevel
         from cfnlint.match import Match  # pylint: disable=cyclic-import
-        from cfnlint.rules import TransformError  # pylint: disable=cyclic-import
+        from cfnlint.rules.errors import TransformError  # pylint: disable=cyclic-import
 
         message = "Error transforming template: {0}"
         return [
-            Match(
-                1,
-                1,
-                1,
-                1,
-                cfn.filename,
-                TransformError(),
-                message.format(str(e)),
+            Match.create(
+                filename=cfn.filename,
+                rule=TransformError(),
+                message=message.format(str(e)),
             )
         ], None
 
@@ -165,7 +162,8 @@ class _Transform:
                         if isinstance(map_value, tuple([list]) + _SCALAR_TYPES):
                             return map_value
                     except Exception as e:  # pylint: disable=broad-exception-caught
-                        # We couldn't resolve the FindInMap so we are going to leave it as it is
+                        # We couldn't resolve the FindInMap so we are going to
+                        # leave it as it is
                         LOGGER.debug("Transform and Fn::FindInMap error: %s", {str(e)})
                     for i, el in enumerate(v):
                         v[i] = self._walk(el, params, cfn)
@@ -207,7 +205,16 @@ class _Transform:
         new_s = deepcopy(s)
         for k, v in params.items():
             if isinstance(v, dict):
-                v = hashlib.md5(json.dumps(v).encode("utf-8")).digest().hex()[0:4]
+                if sys.version_info.major == 3 and sys.version_info.minor > 8:
+                    v = (
+                        hashlib.md5(
+                            json.dumps(v).encode("utf-8"), usedforsecurity=False
+                        )
+                        .digest()
+                        .hex()[0:4]
+                    )
+                else:
+                    v = hashlib.md5(json.dumps(v).encode("utf-8")).digest().hex()[0:4]
             new_s = re.sub(rf"\$\{{{k}\}}", v, new_s)
             new_s = re.sub(rf"\&\{{{k}\}}", re.sub("[^0-9a-zA-Z]+", "", v), new_s)
 
@@ -243,7 +250,7 @@ class _ForEachValue:
 
     # pylint: disable=unused-argument
     def value(
-        self, cfn, params: Optional[Mapping[str, Any]] = None, only_params: bool = False
+        self, cfn, params: Mapping[str, Any] | None = None, only_params: bool = False
     ):
         return self._value
 
@@ -270,14 +277,19 @@ class _FnFindInMapDefaultValue(_ForEachValue):
                 raise _ValueError(
                     "Fn::FindInMap parameter only supports 'DefaultValue'", value
                 )
+            if isinstance(v, list):
+                self._value = [_ForEachValue.create(a) for a in v]
+                return
             self._value = _ForEachValue.create(v)
 
     def value(
-        self, cfn, params: Optional[Mapping[str, Any]] = None, only_params: bool = False
+        self, cfn, params: Mapping[str, Any] | None = None, only_params: bool = False
     ):
         if params is None:
             params = {}
 
+        if isinstance(self._value, list):
+            return [v.value(cfn, params, only_params) for v in self._value]
         return self._value.value(cfn, params, only_params)
 
 
@@ -303,7 +315,7 @@ class _ForEachValueFnFindInMap(_ForEachValue):
     def value(
         self,
         cfn: Any,
-        params: Optional[Mapping[str, Any]] = None,
+        params: Mapping[str, Any] | None = None,
         only_params: bool = False,
         default_on_resolver_failure: bool = True,
     ) -> Any:
@@ -327,7 +339,7 @@ class _ForEachValueFnFindInMap(_ForEachValue):
             ):
                 for k, v in cfn.template.get("Mappings", {}).items():
                     if isinstance(v, dict):
-                        if t_map[1].value(cfn) in v:
+                        if t_map[1].value(cfn, params) in v:
                             t_map[0] = _ForEachValue.create(k)
                             mapping = v
                             break
@@ -352,10 +364,10 @@ class _ForEachValueFnFindInMap(_ForEachValue):
 
         if mapping:
             try:
-                t_map[1].value(cfn)
+                t_map[1].value(cfn, params, only_params)
             except _ResolveError:
                 try:
-                    t_map[2].value(cfn)
+                    t_map[2].value(cfn, params)
                     for k, v in mapping.items():
                         if isinstance(v, dict):
                             if t_map[2].value(cfn, params, only_params) in v:
@@ -400,12 +412,12 @@ class _ForEachValueRef(_ForEachValue):
     def value(
         self,
         cfn: Any,
-        params: Optional[Mapping[str, Any]] = None,
+        params: Mapping[str, Any] | None = None,
         only_params: bool = False,
     ) -> Any:
         if params is None:
             params = {}
-        v = self._ref.value(cfn)
+        v = self._ref.value(cfn, params)
 
         if not isinstance(v, str):
             raise _ResolveError("Can't resolve Fn::Ref", self._obj)
@@ -458,7 +470,6 @@ class _ForEachValueRef(_ForEachValue):
         if not p:
             raise _ResolveError("Can't resolve Fn::Ref", self._obj)
         t = p.get("Type", "String")
-
         if t.startswith("AWS::SSM::Parameter"):
             raise _ResolveError("Can't resolve Fn::Ref", self._obj)
         default = p.get("Default")
@@ -480,9 +491,9 @@ class _ForEachValueRef(_ForEachValue):
 
 class _ForEachCollection:
     def __init__(self, obj: Any) -> None:
-        self._collection: Optional[List[_ForEachValue]] = None
+        self._collection: list[_ForEachValue] | None = None
         self._obj = obj
-        self._fn: Optional[_ForEachValue] = None
+        self._fn: _ForEachValue | None = None
         if isinstance(obj, list):
             self._collection = []
             self._string = obj
@@ -495,8 +506,8 @@ class _ForEachCollection:
         raise _TypeError("Collection must be a list or an object", obj)
 
     def values(
-        self, cfn: Any, collection_cache: MutableMapping[str, str]
-    ) -> Iterable[str]:
+        self, cfn: Any, collection_cache: MutableMapping[str, Any]
+    ) -> Iterator[str | dict[Any, Any]]:
         if self._collection:
             for item in self._collection:
                 try:
@@ -516,7 +527,10 @@ class _ForEachCollection:
                                 yield value
                             else:
                                 raise _ValueError(
-                                    f"Fn::ForEach collection value must be a {_SCALAR_TYPES!r}",
+                                    (
+                                        "Fn::ForEach collection value "
+                                        f"must be a {_SCALAR_TYPES!r}"
+                                    ),
                                     self._obj,
                                 )
                         return
@@ -563,6 +577,6 @@ class _ForEach:
         self._collection = _ForEachCollection(value[1])
         self._output = _ForEachOutput(value[2])
 
-    def items(self, cfn: Any) -> Iterable[Tuple[str, str]]:
+    def items(self, cfn: Any) -> Iterator[str | dict[str, str]]:
         items = self._collection.values(cfn, self._collection_cache)
         yield from iter(items)
